@@ -15,6 +15,6 @@ def execute(freight_hub_json):
 
   available_time = freight_hub_json.get('availableTime')
   if available_time:
-    freight_hub_json_copy['availableTime'] = date.fromtimestamp(int(available_time) / 1000).isoformat()
+    freight_hub_json_copy['availableTime'] = date.fromtimestamp(int(available_time) / 1000)
 
   return LoadSchema().load(freight_hub_json_copy)
